@@ -17,14 +17,18 @@ from .utils import user_email
 
 class EmailAddress(models.Model):
 
-    user = models.ForeignKey(allauth_app_settings.USER_MODEL,
-                             verbose_name=_('user'),
-                             on_delete=models.CASCADE)
-    email = models.EmailField(unique=app_settings.UNIQUE_EMAIL,
-                              max_length=app_settings.EMAIL_MAX_LENGTH,
-                              verbose_name=_('e-mail address'))
-    verified = models.BooleanField(verbose_name=_('verified'), default=False)
-    primary = models.BooleanField(verbose_name=_('primary'), default=False)
+    user = models.ForeignKey(
+        allauth_app_settings.USER_MODEL,
+        verbose_name=_("user"),
+        on_delete=models.CASCADE,
+    )
+    email = models.EmailField(
+        unique=app_settings.UNIQUE_EMAIL,
+        max_length=app_settings.EMAIL_MAX_LENGTH,
+        verbose_name=_("e-mail address"),
+    )
+    verified = models.BooleanField(verbose_name=_("verified"), default=False)
+    primary = models.BooleanField(verbose_name=_("primary"), default=False)
 
     objects = EmailAddressManager()
 
@@ -74,13 +78,14 @@ class EmailAddress(models.Model):
 
 class EmailConfirmation(models.Model):
 
-    email_address = models.ForeignKey(EmailAddress,
-                                      verbose_name=_('e-mail address'),
-                                      on_delete=models.CASCADE)
-    created = models.DateTimeField(verbose_name=_('created'),
-                                   default=timezone.now)
-    sent = models.DateTimeField(verbose_name=_('sent'), null=True)
-    key = models.CharField(verbose_name=_('key'), max_length=64, unique=True)
+    email_address = models.ForeignKey(
+        EmailAddress,
+        verbose_name=_("e-mail address"),
+        on_delete=models.CASCADE,
+    )
+    created = models.DateTimeField(verbose_name=_("created"), default=timezone.now)
+    sent = models.DateTimeField(verbose_name=_("sent"), null=True)
+    key = models.CharField(verbose_name=_("key"), max_length=64, unique=True)
 
     objects = EmailConfirmationManager()
 
@@ -94,59 +99,58 @@ class EmailConfirmation(models.Model):
     @classmethod
     def create(cls, email_address):
         key = get_random_string(64).lower()
-        return cls._default_manager.create(email_address=email_address,
-                                           key=key)
+        return cls._default_manager.create(email_address=email_address, key=key)
 
     def key_expired(self):
-        expiration_date = self.sent \
-            + datetime.timedelta(days=app_settings
-                                 .EMAIL_CONFIRMATION_EXPIRE_DAYS)
+        expiration_date = self.sent + datetime.timedelta(
+            days=app_settings.EMAIL_CONFIRMATION_EXPIRE_DAYS
+        )
         return expiration_date <= timezone.now()
+
     key_expired.boolean = True
 
     def confirm(self, request):
         if not self.key_expired() and not self.email_address.verified:
             email_address = self.email_address
             get_adapter(request).confirm_email(request, email_address)
-            signals.email_confirmed.send(sender=self.__class__,
-                                         request=request,
-                                         email_address=email_address)
+            signals.email_confirmed.send(
+                sender=self.__class__,
+                request=request,
+                email_address=email_address,
+            )
             return email_address
 
     def send(self, request=None, signup=False):
         get_adapter(request).send_confirmation_mail(request, self, signup)
         self.sent = timezone.now()
         self.save()
-        signals.email_confirmation_sent.send(sender=self.__class__,
-                                             request=request,
-                                             confirmation=self,
-                                             signup=signup)
+        signals.email_confirmation_sent.send(
+            sender=self.__class__,
+            request=request,
+            confirmation=self,
+            signup=signup,
+        )
 
 
 class EmailConfirmationHMAC:
-
     def __init__(self, email_address):
         self.email_address = email_address
 
     @property
     def key(self):
-        return signing.dumps(
-            obj=self.email_address.pk,
-            salt=app_settings.SALT)
+        return signing.dumps(obj=self.email_address.pk, salt=app_settings.SALT)
 
     @classmethod
     def from_key(cls, key):
         try:
-            max_age = (
-                60 * 60 * 24 * app_settings.EMAIL_CONFIRMATION_EXPIRE_DAYS)
-            pk = signing.loads(
-                key,
-                max_age=max_age,
-                salt=app_settings.SALT)
+            max_age = 60 * 60 * 24 * app_settings.EMAIL_CONFIRMATION_EXPIRE_DAYS
+            pk = signing.loads(key, max_age=max_age, salt=app_settings.SALT)
             ret = EmailConfirmationHMAC(EmailAddress.objects.get(pk=pk))
-        except (signing.SignatureExpired,
-                signing.BadSignature,
-                EmailAddress.DoesNotExist):
+        except (
+            signing.SignatureExpired,
+            signing.BadSignature,
+            EmailAddress.DoesNotExist,
+        ):
             ret = None
         return ret
 
@@ -154,14 +158,18 @@ class EmailConfirmationHMAC:
         if not self.email_address.verified:
             email_address = self.email_address
             get_adapter(request).confirm_email(request, email_address)
-            signals.email_confirmed.send(sender=self.__class__,
-                                         request=request,
-                                         email_address=email_address)
+            signals.email_confirmed.send(
+                sender=self.__class__,
+                request=request,
+                email_address=email_address,
+            )
             return email_address
 
     def send(self, request=None, signup=False):
         get_adapter(request).send_confirmation_mail(request, self, signup)
-        signals.email_confirmation_sent.send(sender=self.__class__,
-                                             request=request,
-                                             confirmation=self,
-                                             signup=signup)
+        signals.email_confirmation_sent.send(
+            sender=self.__class__,
+            request=request,
+            confirmation=self,
+            signup=signup,
+        )
