@@ -25,18 +25,22 @@ from .provider import GoogleProvider
 @override_settings(
     SOCIALACCOUNT_AUTO_SIGNUP=True,
     ACCOUNT_SIGNUP_FORM_CLASS=None,
-    ACCOUNT_EMAIL_VERIFICATION=account_settings
-    .EmailVerificationMethod.MANDATORY)
+    ACCOUNT_EMAIL_VERIFICATION=account_settings.EmailVerificationMethod.MANDATORY,
+)
 class GoogleTests(OAuth2TestsMixin, TestCase):
     provider_id = GoogleProvider.id
 
-    def get_mocked_response(self,
-                            family_name='Penners',
-                            given_name='Raymond',
-                            name='Raymond Penners',
-                            email="raymond.penners@example.com",
-                            verified_email=True):
-        return MockedResponse(200, """
+    def get_mocked_response(
+        self,
+        family_name="Penners",
+        given_name="Raymond",
+        name="Raymond Penners",
+        email="raymond.penners@example.com",
+        verified_email=True,
+    ):
+        return MockedResponse(
+            200,
+            """
               {"family_name": "%s", "name": "%s",
                "picture": "https://lh5.googleusercontent.com/photo.jpg",
                "locale": "nl", "gender": "male",
@@ -44,29 +48,36 @@ class GoogleTests(OAuth2TestsMixin, TestCase):
                "link": "https://plus.google.com/108204268033311374519",
                "given_name": "%s", "id": "108204268033311374519",
                "verified_email": %s }
-        """ % (family_name,
-               name,
-               email,
-               given_name,
-               (repr(verified_email).lower())))
+        """
+            % (
+                family_name,
+                name,
+                email,
+                given_name,
+                (repr(verified_email).lower()),
+            ),
+        )
 
     def test_google_compelete_login_401(self):
-        from allauth.socialaccount.providers.google.views import \
-            GoogleOAuth2Adapter
+        from allauth.socialaccount.providers.google.views import (
+            GoogleOAuth2Adapter,
+        )
 
         class LessMockedResponse(MockedResponse):
             def raise_for_status(self):
                 if self.status_code != 200:
                     raise HTTPError(None)
+
         request = RequestFactory().get(
-            reverse(self.provider.id + '_login'),
-            dict(process='login'))
+            reverse(self.provider.id + "_login"), dict(process="login")
+        )
 
         adapter = GoogleOAuth2Adapter(request)
         app = adapter.get_provider().get_app(request)
-        token = SocialToken(token='some_token')
+        token = SocialToken(token="some_token")
         response_with_401 = LessMockedResponse(
-            401, """
+            401,
+            """
             {"error": {
               "errors": [{
                 "domain": "global",
@@ -76,47 +87,48 @@ class GoogleTests(OAuth2TestsMixin, TestCase):
                 "location": "Authorization" } ],
               "code": 401,
               "message": "Invalid Credentials" }
-            }""")
+            }""",
+        )
         with patch(
-                'allauth.socialaccount.providers.google.views'
-                '.requests') as patched_requests:
+            "allauth.socialaccount.providers.google.views" ".requests"
+        ) as patched_requests:
             patched_requests.get.return_value = response_with_401
             with self.assertRaises(HTTPError):
                 adapter.complete_login(request, app, token)
 
     def test_username_based_on_email(self):
-        first_name = '明'
-        last_name = '小'
+        first_name = "明"
+        last_name = "小"
         email = "raymond.penners@example.com"
-        self.login(self.get_mocked_response(name=first_name + ' ' + last_name,
-                                            email=email,
-                                            given_name=first_name,
-                                            family_name=last_name,
-                                            verified_email=True))
+        self.login(
+            self.get_mocked_response(
+                name=first_name + " " + last_name,
+                email=email,
+                given_name=first_name,
+                family_name=last_name,
+                verified_email=True,
+            )
+        )
         user = User.objects.get(email=email)
-        self.assertEqual(user.username, 'raymond.penners')
+        self.assertEqual(user.username, "raymond.penners")
 
     def test_email_verified(self):
         test_email = "raymond.penners@example.com"
         self.login(self.get_mocked_response(verified_email=True))
-        email_address = EmailAddress.objects \
-            .get(email=test_email,
-                 verified=True)
-        self.assertFalse(EmailConfirmation.objects
-                         .filter(email_address__email=test_email)
-                         .exists())
+        email_address = EmailAddress.objects.get(email=test_email, verified=True)
+        self.assertFalse(
+            EmailConfirmation.objects.filter(email_address__email=test_email).exists()
+        )
         account = email_address.user.socialaccount_set.all()[0]
-        self.assertEqual(account.extra_data['given_name'], 'Raymond')
+        self.assertEqual(account.extra_data["given_name"], "Raymond")
 
     def test_user_signed_up_signal(self):
         sent_signals = []
 
         def on_signed_up(sender, request, user, **kwargs):
-            sociallogin = kwargs['sociallogin']
-            self.assertEqual(sociallogin.account.provider,
-                             GoogleProvider.id)
-            self.assertEqual(sociallogin.account.user,
-                             user)
+            sociallogin = kwargs["sociallogin"]
+            self.assertEqual(sociallogin.account.provider, GoogleProvider.id)
+            self.assertEqual(sociallogin.account.user, user)
             sent_signals.append(sender)
 
         user_signed_up.connect(on_signed_up)
@@ -127,15 +139,14 @@ class GoogleTests(OAuth2TestsMixin, TestCase):
     def test_email_unverified(self):
         test_email = "raymond.penners@example.com"
         resp = self.login(self.get_mocked_response(verified_email=False))
-        email_address = EmailAddress.objects \
-            .get(email=test_email)
+        email_address = EmailAddress.objects.get(email=test_email)
         self.assertFalse(email_address.verified)
-        self.assertTrue(EmailConfirmation.objects
-                        .filter(email_address__email=test_email)
-                        .exists())
+        self.assertTrue(
+            EmailConfirmation.objects.filter(email_address__email=test_email).exists()
+        )
         self.assertTemplateUsed(
-            resp,
-            'account/email/email_confirmation_signup_subject.txt')
+            resp, "account/email/email_confirmation_signup_subject.txt"
+        )
 
     def test_email_verified_stashed(self):
         # http://slacy.com/blog/2012/01/how-to-set-session-variables-in-django-unit-tests/
@@ -143,7 +154,7 @@ class GoogleTests(OAuth2TestsMixin, TestCase):
         store = engine.SessionStore()
         store.save()
         self.client.cookies[settings.SESSION_COOKIE_NAME] = store.session_key
-        request = RequestFactory().get('/')
+        request = RequestFactory().get("/")
         request.session = self.client.session
         adapter = get_adapter(request)
         test_email = "raymond.penners@example.com"
@@ -151,57 +162,44 @@ class GoogleTests(OAuth2TestsMixin, TestCase):
         request.session.save()
 
         self.login(self.get_mocked_response(verified_email=False))
-        email_address = EmailAddress.objects \
-            .get(email=test_email)
+        email_address = EmailAddress.objects.get(email=test_email)
         self.assertTrue(email_address.verified)
         self.assertFalse(
-            EmailConfirmation.objects.filter(
-                email_address__email=test_email).exists())
+            EmailConfirmation.objects.filter(email_address__email=test_email).exists()
+        )
 
     def test_account_connect(self):
         email = "user@example.com"
-        user = User.objects.create(username='user',
-                                   is_active=True,
-                                   email=email)
-        user.set_password('test')
+        user = User.objects.create(username="user", is_active=True, email=email)
+        user.set_password("test")
         user.save()
-        EmailAddress.objects.create(user=user,
-                                    email=email,
-                                    primary=True,
-                                    verified=True)
-        self.client.login(username=user.username,
-                          password='test')
-        self.login(self.get_mocked_response(verified_email=True),
-                   process='connect')
+        EmailAddress.objects.create(user=user, email=email, primary=True, verified=True)
+        self.client.login(username=user.username, password="test")
+        self.login(self.get_mocked_response(verified_email=True), process="connect")
         # Check if we connected...
-        self.assertTrue(SocialAccount.objects.filter(
-            user=user,
-            provider=GoogleProvider.id).exists())
+        self.assertTrue(
+            SocialAccount.objects.filter(user=user, provider=GoogleProvider.id).exists()
+        )
         # For now, we do not pick up any new e-mail addresses on connect
         self.assertEqual(EmailAddress.objects.filter(user=user).count(), 1)
-        self.assertEqual(EmailAddress.objects.filter(
-            user=user,
-            email=email).count(), 1)
+        self.assertEqual(EmailAddress.objects.filter(user=user, email=email).count(), 1)
 
     @override_settings(
-        ACCOUNT_EMAIL_VERIFICATION=account_settings
-        .EmailVerificationMethod.MANDATORY,
-        SOCIALACCOUNT_EMAIL_VERIFICATION=account_settings
-        .EmailVerificationMethod.NONE
+        ACCOUNT_EMAIL_VERIFICATION=account_settings.EmailVerificationMethod.MANDATORY,
+        SOCIALACCOUNT_EMAIL_VERIFICATION=account_settings.EmailVerificationMethod.NONE,
     )
     def test_social_email_verification_skipped(self):
         test_email = "raymond.penners@example.com"
         self.login(self.get_mocked_response(verified_email=False))
         email_address = EmailAddress.objects.get(email=test_email)
         self.assertFalse(email_address.verified)
-        self.assertFalse(EmailConfirmation.objects.filter(
-            email_address__email=test_email).exists())
+        self.assertFalse(
+            EmailConfirmation.objects.filter(email_address__email=test_email).exists()
+        )
 
     @override_settings(
-        ACCOUNT_EMAIL_VERIFICATION=account_settings
-        .EmailVerificationMethod.OPTIONAL,
-        SOCIALACCOUNT_EMAIL_VERIFICATION=account_settings
-        .EmailVerificationMethod.OPTIONAL
+        ACCOUNT_EMAIL_VERIFICATION=account_settings.EmailVerificationMethod.OPTIONAL,
+        SOCIALACCOUNT_EMAIL_VERIFICATION=account_settings.EmailVerificationMethod.OPTIONAL,
     )
     def test_social_email_verification_optional(self):
         self.login(self.get_mocked_response(verified_email=False))
@@ -212,11 +210,11 @@ class GoogleTests(OAuth2TestsMixin, TestCase):
 
 @override_settings(
     SOCIALACCOUNT_PROVIDERS={
-        'google': {
-            'APP': {
-                'client_id': 'app123id',
-                'key': 'google',
-                'secret': 'dummy'
+        "google": {
+            "APP": {
+                "client_id": "app123id",
+                "key": "google",
+                "secret": "dummy",
             }
         }
     }
@@ -225,4 +223,5 @@ class AppInSettingsTests(GoogleTests):
     """
     Run the same set of tests but without having a SocialApp entry.
     """
+
     pass
