@@ -8,8 +8,12 @@ from allauth.tests import MockedResponse
 from .provider import RedditProvider
 
 
-class RedditTests(create_oauth2_tests(registry.by_id(
-        RedditProvider.id))):
+class RedditTests(create_oauth2_tests(registry.by_id(RedditProvider.id))):
     def get_mocked_response(self):
-        return [MockedResponse(200, """{
-        "name": "wayward710"}""")]
+        return [
+            MockedResponse(
+                200,
+                """{
+        "name": "wayward710"}""",
+            )
+        ]
