@@ -11,16 +11,15 @@ from .provider import TwentyThreeAndMeProvider
 
 class TwentyTreeAndMeOAuth2Adapter(OAuth2Adapter):
     provider_id = TwentyThreeAndMeProvider.id
-    access_token_url = 'https://api.23andme.com/token'
-    authorize_url = 'https://api.23andme.com/authorize'
-    profile_url = 'https://api.23andme.com/1/user/'
+    access_token_url = "https://api.23andme.com/token"
+    authorize_url = "https://api.23andme.com/authorize"
+    profile_url = "https://api.23andme.com/1/user/"
 
     def complete_login(self, request, app, token, **kwargs):
-        headers = {'Authorization': 'Bearer {0}'.format(token.token)}
+        headers = {"Authorization": "Bearer {0}".format(token.token)}
         resp = requests.get(self.profile_url, headers=headers)
         extra_data = resp.json()
-        return self.get_provider().sociallogin_from_response(
-            request, extra_data)
+        return self.get_provider().sociallogin_from_response(request, extra_data)
 
 
 oauth2_login = OAuth2LoginView.adapter_view(TwentyTreeAndMeOAuth2Adapter)
