@@ -8,7 +8,9 @@ class WindowsLiveTests(OAuth2TestsMixin, TestCase):
     provider_id = WindowsLiveProvider.id
 
     def get_mocked_response(self):
-        return MockedResponse(200, """
+        return MockedResponse(
+            200,
+            """
         {
           "first_name": "James",
           "last_name": "Smith",
@@ -25,4 +27,5 @@ class WindowsLiveTests(OAuth2TestsMixin, TestCase):
           "updated_time": "2014-02-07T00:35:27+0000",
           "id": "83605e110af6ff98"
         }
-        """)
+        """,
+        )
